<?php

namespace Assetdocs\Branchmaster\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Assetdocs\Branchmaster\Interfaces\BranchmasterRepositoryInterface;
use Assetdocs\Branchmaster\Repositories\Presenter\BranchmasterItemTransformer;

/**
 * Pubic API controller class.
 */
class BranchmasterApiController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Assetdocs\Branchmaster\Interfaces\BranchmasterRepositoryInterface $branchmaster
     *
     * @return type
     */
    public function __construct(BranchmasterRepositoryInterface $branchmaster)
    {
        $this->middleware('api');

        $this->repository = $branchmaster;
        parent::__construct();
    }

    /**
     * Show branchmaster's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $branchmasters = $this->repository
            ->pushCriteria(new \Assetdocs\Branchmaster\Repositories\Criteria\BranchmasterPublicCriteria())
            ->setPresenter('\\Assetdocs\\Branchmaster\\Repositories\\Presenter\\BranchmasterListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $branchmasters['code'] = 2000;
        return response()->json($branchmasters)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show branchmaster.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $branchmaster = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($branchmaster)) {
            $branchmaster         = $this->itemPresenter($module, new BranchmasterItemTransformer);
            $branchmaster['code'] = 2001;
            return response()->json($branchmaster)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
