<?php

namespace Assetdocs\Branchmaster\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Assetdocs\Branchmaster\Interfaces\BranchmasterRepositoryInterface;

class BranchmasterController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Assetdocs\Branchmaster\Interfaces\BranchmasterRepositoryInterface $branchmaster
     *
     * @return type
     */
    public function __construct(BranchmasterRepositoryInterface $branchmaster)
    {
        $this->middleware('web');
        $this->setupTheme(config('theme.themes.public.theme'), config('theme.themes.public.layout'));

        $this->repository = $branchmaster;
        parent::__construct();
    }

    /**
     * Show branchmaster's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $branchmasters = $this->repository
            ->pushCriteria(new \Assetdocs\Branchmaster\Repositories\Criteria\BranchmasterPublicCriteria())
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        return $this->theme->of('branchmaster::public.branchmaster.index', compact('branchmasters'))->render();
    }

    /**
     * Show branchmaster.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $branchmaster = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->theme->of('branchmaster::public.branchmaster.show', compact('branchmaster'))->render();
    }
}
