<?php

namespace Assetdocs\Branchmaster\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Form;
use Assetdocs\Branchmaster\Http\Requests\BranchmasterUserWebRequest;
use Assetdocs\Branchmaster\Interfaces\BranchmasterRepositoryInterface;
use Assetdocs\Branchmaster\Models\Branchmaster;

class BranchmasterUserController extends BaseController
{
    /**
     * The authentication guard that should be used.
     *
     * @var string
     */
    protected $guard = 'web';

    /**
     * Initialize branchmaster controller.
     *
     * @param type BranchmasterRepositoryInterface $branchmaster
     *
     * @return type
     */
    public function __construct(BranchmasterRepositoryInterface $branchmaster)
    {
        $this->middleware('web');
        $this->middleware('auth:web');
        $this->setupTheme(config('theme.themes.user.theme'), config('theme.themes.user.layout'));

        $this->repository = $branchmaster;
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(BranchmasterUserWebRequest $request)
    {
        $this->repository->pushCriteria(new \Assetdocs\Branchmaster\Repositories\Criteria\BranchmasterUserCriteria());
        $branchmasters = $this->repository->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();

        $this->theme->prependTitle(trans('branchmaster::branchmaster.names').' :: ');

        return $this->theme->of('branchmaster::user.branchmaster.index', compact('branchmasters'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param Branchmaster $branchmaster
     *
     * @return Response
     */
    public function show(BranchmasterUserWebRequest $request, Branchmaster $branchmaster)
    {
        Form::populate($branchmaster);

        return $this->theme->of('branchmaster::user.branchmaster.show', compact('branchmaster'))->render();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(BranchmasterUserWebRequest $request)
    {

        $branchmaster = $this->repository->newInstance([]);
        Form::populate($branchmaster);

        return $this->theme->of('branchmaster::user.branchmaster.create', compact('branchmaster'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(BranchmasterUserWebRequest $request)
    {
        try {
            $attributes = $request->all();
            $attributes['user_id'] = user_id();
            $branchmaster = $this->repository->create($attributes);

            return redirect(trans_url('/user/branchmaster/branchmaster'))
                -> with('message', trans('messages.success.created', ['Module' => trans('branchmaster::branchmaster.name')]))
                -> with('code', 201);

        } catch (Exception $e) {
            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param Branchmaster $branchmaster
     *
     * @return Response
     */
    public function edit(BranchmasterUserWebRequest $request, Branchmaster $branchmaster)
    {

        Form::populate($branchmaster);

        return $this->theme->of('branchmaster::user.branchmaster.edit', compact('branchmaster'))->render();
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param Branchmaster $branchmaster
     *
     * @return Response
     */
    public function update(BranchmasterUserWebRequest $request, Branchmaster $branchmaster)
    {
        try {
            $this->repository->update($request->all(), $branchmaster->getRouteKey());

            return redirect(trans_url('/user/branchmaster/branchmaster'))
                ->with('message', trans('messages.success.updated', ['Module' => trans('branchmaster::branchmaster.name')]))
                ->with('code', 204);

        } catch (Exception $e) {
            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(BranchmasterUserWebRequest $request, Branchmaster $branchmaster)
    {
        try {
            $this->repository->delete($branchmaster->getRouteKey());
            return response()->json([
                'message'  => trans('messages.success.deleted', ['Module' => trans('branchmaster::branchmaster.name')]),
                'code'     => 202,
                'redirect' => trans_url('/user/branchmaster/branchmaster/0'),
            ], 202);

        } catch (Exception $e) {

            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);

        }
    }
}
