<?php

namespace Assetdocs\Branchmaster\Policies;

use App\User;
use Illuminate\Auth\Access\HandlesAuthorization;
use Assetdocs\Branchmaster\Models\Branchmaster;

class BranchmasterPolicy
{
    use HandlesAuthorization;

    /**
     * Determine if the given user can view the branchmaster.
     *
     * @param User $user
     * @param Branchmaster $branchmaster
     *
     * @return bool
     */
    public function view(User $user, Branchmaster $branchmaster)
    {
        if ($user->canDo('branchmaster.branchmaster.view') && $user->is('admin')) {
            return true;
        }

        return $user->id === $branchmaster->user_id;
    }

    /**
     * Determine if the given user can create a branchmaster.
     *
     * @param User $user
     * @param Branchmaster $branchmaster
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('branchmaster.branchmaster.create');
    }

    /**
     * Determine if the given user can update the given branchmaster.
     *
     * @param User $user
     * @param Branchmaster $branchmaster
     *
     * @return bool
     */
    public function update(User $user, Branchmaster $branchmaster)
    {
        if ($user->canDo('branchmaster.branchmaster.update') && $user->is('admin')) {
            return true;
        }

        return $user->id === $branchmaster->user_id;
    }

    /**
     * Determine if the given user can delete the given branchmaster.
     *
     * @param User $user
     * @param Branchmaster $branchmaster
     *
     * @return bool
     */
    public function destroy(User $user, Branchmaster $branchmaster)
    {
        if ($user->canDo('branchmaster.branchmaster.delete') && $user->is('admin')) {
            return true;
        }

        return $user->id === $branchmaster->user_id;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
