<?php

namespace Assetdocs\Branchmaster\Providers;

use Illuminate\Support\ServiceProvider;

class BranchmasterServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../../../resources/views', 'branchmaster');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../../../resources/lang', 'branchmaster');

        // Call pblish redources function
        $this->publishResources();

        include __DIR__ . '/../Http/routes.php';
    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('branchmaster', function ($app) {
            return $this->app->make('Assetdocs\Branchmaster\Branchmaster');
        });

        // Bind Branchmaster to repository
        $this->app->bind(
            \Assetdocs\Branchmaster\Interfaces\BranchmasterRepositoryInterface::class,
            \Assetdocs\Branchmaster\Repositories\Eloquent\BranchmasterRepository::class
        );

        $this->app->register(\Assetdocs\Branchmaster\Providers\AuthServiceProvider::class);
        $this->app->register(\Assetdocs\Branchmaster\Providers\EventServiceProvider::class);
        $this->app->register(\Assetdocs\Branchmaster\Providers\RouteServiceProvider::class);
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['branchmaster'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../../../config/config.php' => config_path('package/branchmaster.php')], 'config');

        // Publish view files
        $this->publishes([__DIR__ . '/../../../../resources/views' => base_path('resources/views/vendor/branchmaster')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../../../resources/lang' => base_path('resources/lang/vendor/branchmaster')], 'lang');

        // Publish migrations
        $this->publishes([__DIR__ . '/../../../../database/migrations/' => base_path('database/migrations')], 'migrations');

        // Publish seeds
        $this->publishes([__DIR__ . '/../../../../database/seeds/' => base_path('database/seeds')], 'seeds');

        // Publish public folder.
        $this->publishes([__DIR__ . '/../../../../public' => public_path('/')], 'public');
    }
}
